==> haskell-tasty-th-0.1.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-LADFpiDcpz67A9iRpLHXtM
key: tasty-th-0.1.7-LADFpiDcpz67A9iRpLHXtM
license: BSD3
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.TH
abi: 764569ea55c5e3da7077fe7ebdc6fad8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-LADFpiDcpz67A9iRpLHXtM
depends:
    base-4.10.1.0 haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp
    tasty-0.12.0.1-K5iEyMvEidlGcZs8hbeAn template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp=9e7d1f47a4d57e9fb92fbdd8cc305af5
             tasty-0.12.0.1-K5iEyMvEidlGcZs8hbeAn=2ac04345cccf8580d02b85e546c5808a
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-C49FG1f73v94vyD4OVbCtY
key: tasty-th-0.1.7-C49FG1f73v94vyD4OVbCtY
license: BSD3
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.TH
abi: f55bde89f31bc830630ebec25418baf4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-C49FG1f73v94vyD4OVbCtY
depends:
    base-4.10.1.0 haskell-src-exts-1.20.2-HF52XUxuMxx6D9UVMuMENI
    tasty-1.0.1.1-2tjeWKLif3u1C3uXO5t79i template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             haskell-src-exts-1.20.2-HF52XUxuMxx6D9UVMuMENI=e2f5f29a6e1f816845f02dd93c2aab1d
             tasty-1.0.1.1-2tjeWKLif3u1C3uXO5t79i=b149451f508a3eba0c2eaff8de3a6f01
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
